// tòmò web analytics
// Copyright since 2011 by Yves Goergen
// Website: http://unclassified.de/go/tomo
// Licence: GNU General Public License (GPL) Version 3
// Encoding: UTF-8 (without BOM) (auto-detect: °°°°°)
//
// This file contains JavaScript code used in the log/statistics viewer.


function updateContentHeight()
{
	var h = coati.dom.height("#page-header");
	$("#page-content").style.paddingTop = (h + 16) + "px";
}

// Align page-content at page-header
coati.dom.whenDomLoaded(updateContentHeight);


// Specifies the active tab for each tab group.
var activeTab = {};

// Keeps references to each tab groups headers and pages for faster access
var tabHeaders = {};
var tabPages = {};

// Activates a tab by its name in a tab group.
// This function is called from the event handler that is assigned in initializeTabs.
//
function activateTab(tabHeaderId, name)
{
	if (activeTab[tabHeaderId])
	{
		coati.dom.hide(tabPages[tabHeaderId][activeTab[tabHeaderId]]);
		coati.dom.removeClass(tabHeaders[tabHeaderId][activeTab[tabHeaderId]], "selected");
	}

	activeTab[tabHeaderId] = name;

	if (activeTab[tabHeaderId])
	{
		coati.dom.show(tabPages[tabHeaderId][activeTab[tabHeaderId]]);
		coati.dom.addClass(tabHeaders[tabHeaderId][activeTab[tabHeaderId]], "selected");
	}
	
	updateContentHeight();
}

// Initializes all tabs in the specified tab group.
//
function initializeTabs(tabHeaderId)
{
	tabHeaders[tabHeaderId] = {};
	tabPages[tabHeaderId] = {};
	
	var firstPage;
	
	coati.array.each($$("#" + tabHeaderId + " a"), function(i) {
		var page = i.getAttribute("data-tabpage");
		if (!firstPage)
		{
			firstPage = page;
		}
		
		tabHeaders[tabHeaderId][page] = i;
		tabPages[tabHeaderId][page] = $("#" + page);
		
		coati.dom.addKeyEvent(i, "Enter", function(e) {
			if (activeTab[tabHeaderId] != page) {
				activateTab(tabHeaderId, page);
			}
			else {
				activateTab(tabHeaderId, undefined);
			}
			e.target.blur();
		});
		coati.dom.addEvent(i, "mousedown", function(e) {
			if (e.button == 0) {   // left button
				if (activeTab[tabHeaderId] != page) {
					activateTab(tabHeaderId, page);
				}
				else {
					activateTab(tabHeaderId, undefined);
				}
				e.target.blur();
			}
		});
		
		coati.dom.hide(tabPages[tabHeaderId][page]);
	});

	activateTab(tabHeaderId, firstPage);
}

function filterOpChanged(select)
{
	var col = select.getAttribute("data-column");
	if (select.value == "between")
	{
		coati.dom.show("#input_" + col + "_value2");
	}
	else
	{
		coati.dom.hide("#input_" + col + "_value2");
	}
	if (select.value == "isnull")
	{
		coati.dom.hide("#input_" + col + "_value");
	}
	else
	{
		coati.dom.show("#input_" + col + "_value");
	}
}

function removeFilterColumn(col)
{
	var tr = $("#filter_row_" + col);
	if (tr)
	{
		tr.parentNode.removeChild(tr);
	}
}

var trdict = {};

function addFilterColumn(col, coldesc)
{
	if ($("#filter_row_" + col))
	{
		// The column is already in the filter
		activateTab("addColumnsTab", "filterTab");
		return;
	}
	
	var type = trdict['coltype:' + col];
	
	var html = "";
	html += '<tr class="va" id="filter_row_' + col + '">';

	html += '<td>';
	html += '<a href="javascript:undefined" onclick="removeFilterColumn(\'' + col + '\')" title="' + trdict['remove column'] + '">' + trdict['icon.delete'] + '</a>';

	html += '<span title="' + coldesc + '">' + trdict['column:' + col] + '<input type="hidden" name="filtercol[]" value="' + col + '"></span>';
	html += '</td>';

	html += '<td><label><input type="checkbox" name="' + col + '_not" value="1">' + trdict['not'] + '</label></td>';

	html += '<td><select name="' + col + '_op" id="filterop_' + col + '" onchange="filterOpChanged(this)" data-column="' + col + '">';
	switch (type)
	{
		case 'int':
			html += '<option value="eq">=</option>';
			html += '<option value="lt">&lt;</option>';
			html += '<option value="lte">&#x2264;</option>';
			html += '<option value="gt">&gt;</option>';
			html += '<option value="gte">&#x2265;</option>';
			html += '<option value="ne">&#x2260;</option>';
			html += '<option value="between">' + trdict['op:between'] + '</option>';
			html += '<option value="isnull">' + trdict['op:isnull'] + '</option>';
			break;
		case 'datetime':
			html += '<option value="eq">=</option>';
			html += '<option value="lt">&lt;</option>';
			html += '<option value="lte">&#x2264;</option>';
			html += '<option value="gt">&gt;</option>';
			html += '<option value="gte">&#x2265;</option>';
			html += '<option value="ne">&#x2260;</option>';
			html += '<option value="between">' + trdict['op:between'] + '</option>';
			html += '<option value="inday">' + trdict['op:inday'] + '</option>';
			html += '<option value="inmonth">' + trdict['op:inmonth'] + '</option>';
			html += '<option value="inyear">' + trdict['op:inyear'] + '</option>';
			html += '<option value="isnull">' + trdict['op:isnull'] + '</option>';
			break;
		case 'bool':
			html += '<option value="eq">' + trdict['set'] + '</option>';
			html += '<option value="isnull">' + trdict['op:isnull'] + '</option>';
			break;
		case 'string':
			html += '<option value="eq">=</option>';
			html += '<option value="lt">&lt;</option>';
			html += '<option value="lte">&#x2264;</option>';
			html += '<option value="gt">&gt;</option>';
			html += '<option value="gte">&#x2265;</option>';
			html += '<option value="ne">&#x2260;</option>';
			html += '<option value="between">' + trdict['op:between'] + '</option>';
			html += '<option value="contains">' + trdict['op:contains'] + '</option>';
			html += '<option value="startswith">' + trdict['op:startswith'] + '</option>';
			html += '<option value="endswith">' + trdict['op:endswith'] + '</option>';
			html += '<option value="isnull">' + trdict['op:isnull'] + '</option>';
			break;
	}
	html += '</select></td>';

	html += '<td>';
	switch (type)
	{
		case 'int':
			html += '<span id="input_' + col + '_value">';
			html += '<input type="text" name="' + col + '_value" size="20"> ';
			html += '<span id="input_' + col + '_value2">';
			html += trdict['op:between-and'] + ' <input type="text" name="' + col + '_value2" size="20">';
			html += '</span>';
			html += '</span>';
			break;
		case 'datetime':
			html += '<span id="input_' + col + '_value">';
			html += '<input type="text" name="' + col + '_value" size="20"> ';
			html += '<span id="input_' + col + '_value2">';
			html += trdict['op:between-and'] + ' <input type="text" name="' + col + '_value2" size="20">';
			html += '</span>';
			html += '</span>';
			break;
		case 'bool':
			html += '<input type="hidden" name="' + col + '_value" value="1">';
			break;
		case 'string':
			html += '<span id="input_' + col + '_value">';
			html += '<input type="text" name="' + col + '_value" size="35"> ';
			html += '<span id="input_' + col + '_value2">';
			html += trdict['op:between-and'] + ' <input type="text" name="' + col + '_value2" size="15">';
			html += '</span>';
			html += '</span>';
			break;
	}
	html += '</td>';

	html += '<td><label><input type="checkbox" name="' + col + '_disabled" value="1">' + trdict['disabled'] + '</label></td>';

	html += '</tr>';

	$("#filter-table").innerHTML += html;

	filterOpChanged($("#filterop_" + col));
	activateTab("addColumnsTab", "filterTab");
}
